"use strict";

require("core-js/modules/web.dom.iterable");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _qs = _interopRequireDefault(require("qs"));

var _reactRedux = require("react-redux");

var _reactBootstrap = require("react-bootstrap");

var _reactRouter = require("react-router");

var _icon = _interopRequireDefault(require("../narrative/icon"));

var callTakerActions = _interopRequireWildcard(require("../../actions/call-taker"));

var fieldTripActions = _interopRequireWildcard(require("../../actions/field-trip"));

var _ui = require("../../actions/ui");

var _config = require("../../util/config");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// TODO: make menu items configurable via props/config
class AppMenu extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "_showRouteViewer", () => {
      this.props.setMainPanelContent(_ui.MainPanelContent.ROUTE_VIEWER);
    });

    _defineProperty(this, "_startOver", () => {
      const {
        location,
        reactRouterConfig
      } = this.props;
      const {
        search
      } = location;
      let startOverUrl = '/';

      if (reactRouterConfig && reactRouterConfig.basename) {
        startOverUrl += reactRouterConfig.basename;
      } // If search contains sessionId, preserve this so that the current session
      // is not lost when the page reloads.


      if (search) {
        const params = _qs.default.parse(search, {
          ignoreQueryPrefix: true
        });

        const {
          sessionId
        } = params;

        if (sessionId) {
          startOverUrl += `?${_qs.default.stringify({
            sessionId
          })}`;
        }
      }

      window.location.href = startOverUrl;
    });
  }

  render() {
    const {
      callTakerEnabled,
      fieldTripEnabled,
      languageConfig,
      mailablesEnabled,
      resetAndToggleCallHistory,
      resetAndToggleFieldTrips,
      toggleMailables
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", {
      "aria-label": "app-menu",
      className: "app-menu",
      role: "navigation"
    }, /*#__PURE__*/_react.default.createElement(_reactBootstrap.DropdownButton, {
      "aria-label": "Application Menu",
      className: "app-menu-button",
      id: "app-menu",
      noCaret: true,
      title: /*#__PURE__*/_react.default.createElement(_icon.default, {
        type: "bars"
      })
    }, /*#__PURE__*/_react.default.createElement(_reactBootstrap.MenuItem, {
      onClick: this._showRouteViewer
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "bus"
    }), " ", languageConfig.routeViewer || 'Route Viewer'), callTakerEnabled && /*#__PURE__*/_react.default.createElement(_reactBootstrap.MenuItem, {
      onClick: resetAndToggleCallHistory
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "history"
    }), " Call History"), fieldTripEnabled && /*#__PURE__*/_react.default.createElement(_reactBootstrap.MenuItem, {
      onClick: resetAndToggleFieldTrips
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "graduation-cap"
    }), " Field Trip"), mailablesEnabled && /*#__PURE__*/_react.default.createElement(_reactBootstrap.MenuItem, {
      onClick: toggleMailables
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "envelope"
    }), " Mailables"), /*#__PURE__*/_react.default.createElement(_reactBootstrap.MenuItem, {
      onClick: this._startOver
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "undo"
    }), " Start Over")));
  }

} // connect to the redux store


_defineProperty(AppMenu, "propTypes", {
  setMainPanelContent: _propTypes.default.func
});

const mapStateToProps = (state, ownProps) => {
  const {
    language
  } = state.otp.config;
  return {
    callTakerEnabled: (0, _config.isModuleEnabled)(state, _config.Modules.CALL_TAKER),
    fieldTripEnabled: (0, _config.isModuleEnabled)(state, _config.Modules.FIELD_TRIP),
    languageConfig: language,
    mailablesEnabled: (0, _config.isModuleEnabled)(state, _config.Modules.MAILABLES)
  };
};

const mapDispatchToProps = {
  resetAndToggleCallHistory: callTakerActions.resetAndToggleCallHistory,
  resetAndToggleFieldTrips: fieldTripActions.resetAndToggleFieldTrips,
  setMainPanelContent: _ui.setMainPanelContent,
  toggleMailables: callTakerActions.toggleMailables
};

var _default = (0, _reactRouter.withRouter)((0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(AppMenu));

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=app-menu.js