"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom.iterable");

var _coreUtils = _interopRequireDefault(require("@opentripplanner/core-utils"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactBootstrap = require("react-bootstrap");

var _velocityReact = require("velocity-react");

var _reactRedux = require("react-redux");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _icon = _interopRequireDefault(require("../narrative/icon"));

var _ui = require("../../actions/ui");

var _api = require("../../actions/api");

var _contexts = require("../../util/contexts");

var _viewer = require("../../util/viewer");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Determine the appropriate contrast color for text (white or black) based on
 * the input hex string (e.g., '#ff00ff') value.
 *
 * From https://stackoverflow.com/a/11868398/915811
 *
 * TODO: Move to @opentripplanner/core-utils once otp-rr uses otp-ui library.
 */
function getContrastYIQ(hexcolor) {
  hexcolor = hexcolor.replace('#', '');
  const r = parseInt(hexcolor.substr(0, 2), 16);
  const g = parseInt(hexcolor.substr(2, 2), 16);
  const b = parseInt(hexcolor.substr(4, 2), 16);
  const yiq = (r * 299 + g * 587 + b * 114) / 1000;
  return yiq >= 128 ? '000000' : 'ffffff';
}

class RouteViewer extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "_backClicked", () => this.props.setMainPanelContent(null));
  }

  componentDidMount() {
    this.props.findRoutes();
  }

  render() {
    const {
      findRoute,
      hideBackButton,
      languageConfig,
      routes,
      setViewedRoute,
      transitOperators,
      viewedRoute
    } = this.props;
    const sortedRoutes = routes ? Object.values(routes).sort(_coreUtils.default.route.makeRouteComparator(transitOperators)) : [];
    return /*#__PURE__*/_react.default.createElement("div", {
      className: "route-viewer"
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: "route-viewer-header"
    }, !hideBackButton && /*#__PURE__*/_react.default.createElement("div", {
      className: "back-button-container"
    }, /*#__PURE__*/_react.default.createElement(_reactBootstrap.Button, {
      bsSize: "small",
      onClick: this._backClicked
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      type: "arrow-left"
    }), "Back")), /*#__PURE__*/_react.default.createElement("div", {
      className: "header-text"
    }, languageConfig.routeViewer || 'Route Viewer'), /*#__PURE__*/_react.default.createElement("div", {
      className: ""
    }, languageConfig.routeViewerDetails), /*#__PURE__*/_react.default.createElement("div", {
      style: {
        clear: 'both'
      }
    })), /*#__PURE__*/_react.default.createElement("div", {
      className: "route-viewer-body"
    }, sortedRoutes.map(route => {
      // Find operator based on agency_id (extracted from OTP route ID).
      const operator = _coreUtils.default.route.getTransitOperatorFromOtpRoute(route, transitOperators) || {};
      return /*#__PURE__*/_react.default.createElement(RouteRow, {
        findRoute: findRoute,
        isActive: viewedRoute && viewedRoute.routeId === route.id,
        key: route.id,
        operator: operator,
        route: route,
        setViewedRoute: setViewedRoute
      });
    })));
  }

}

_defineProperty(RouteViewer, "propTypes", {
  hideBackButton: _propTypes.default.bool,
  routes: _propTypes.default.object
});

const StyledRouteRow = _styledComponents.default.div`
  background-color: ${props => props.isActive ? '#f6f8fa' : 'white'};
  border-bottom: 1px solid gray;
`;
const RouteRowButton = (0, _styledComponents.default)(_reactBootstrap.Button)`
  align-items: center;
  display: flex;
  padding: 6px;
  width: 100%;
`;
const RouteRowElement = _styledComponents.default.span`
`;
const OperatorImg = _styledComponents.default.img`
  height: 25px;
  margin-right: 8px;
`;
const ModeIconElement = _styledComponents.default.span`
  display: inline-block;
  vertical-align: bottom;
  height: 22px;
`;
const RouteNameElement = (0, _styledComponents.default)(_reactBootstrap.Label)`
  background-color: ${props => props.backgroundColor === '#ffffff' || props.backgroundColor === 'white' ? 'rgba(0,0,0,0)' : props.backgroundColor};
  color: ${props => props.color};
  flex: 0 1 auto;
  font-size: medium;
  font-weight: 400;
  margin-left: ${props => props.backgroundColor === '#ffffff' || props.backgroundColor === 'white' ? 0 : '8px'};
  margin-top: 2px;
  overflow: hidden;
  text-overflow: ellipsis;
`;
const RouteDetails = _styledComponents.default.div`
  padding: 8px;
`;

class RouteRow extends _react.PureComponent {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "_onClick", () => {
      const {
        findRoute,
        isActive,
        route,
        setViewedRoute
      } = this.props;

      if (isActive) {
        // Deselect current route if active.
        setViewedRoute({
          routeId: null
        });
      } else {
        // Otherwise, set active and fetch route patterns.
        findRoute({
          routeId: route.id
        });
        setViewedRoute({
          routeId: route.id
        });
      }
    });
  }

  getCleanRouteLongName({
    longNameSplitter,
    route
  }) {
    let longName = '';

    if (route.longName) {
      // Attempt to split route name if splitter is defined for operator (to
      // remove short name value from start of long name value).
      const nameParts = route.longName.split(longNameSplitter);
      longName = longNameSplitter && nameParts.length > 1 ? nameParts[1] : route.longName; // If long name and short name are identical, set long name to be an empty
      // string.

      if (longName === route.shortName) longName = '';
    }

    return longName;
  }

  render() {
    const {
      isActive,
      operator,
      route
    } = this.props;
    const {
      ModeIcon
    } = this.context;
    const {
      defaultRouteColor,
      defaultRouteTextColor,
      longNameSplitter
    } = operator || {};
    const backgroundColor = `#${defaultRouteColor || route.color || 'ffffff'}`; // NOTE: text color is not a part of short response route object, so there
    // is no way to determine from OTP what the text color should be if the
    // background color is, say, black. Instead, determine the appropriate
    // contrast color and use that if no text color is available.

    const contrastColor = getContrastYIQ(backgroundColor);
    const color = `#${defaultRouteTextColor || route.textColor || contrastColor}`; // Default long name is empty string (long name is an optional GTFS value).

    const longName = this.getCleanRouteLongName({
      longNameSplitter,
      route
    });
    return /*#__PURE__*/_react.default.createElement(StyledRouteRow, {
      isActive: isActive
    }, /*#__PURE__*/_react.default.createElement(RouteRowButton, {
      className: "clear-button-formatting",
      onClick: this._onClick
    }, /*#__PURE__*/_react.default.createElement(RouteRowElement, null, operator && operator.logo && /*#__PURE__*/_react.default.createElement(OperatorImg, {
      alt: `${operator.name} logo`,
      src: operator.logo
    })), /*#__PURE__*/_react.default.createElement(ModeIconElement, null, /*#__PURE__*/_react.default.createElement(ModeIcon, {
      height: 22,
      mode: (0, _viewer.getModeFromRoute)(route),
      width: 22
    })), /*#__PURE__*/_react.default.createElement(RouteNameElement, {
      backgroundColor: backgroundColor,
      color: color,
      title: `${route.shortName} ${longName}`
    }, /*#__PURE__*/_react.default.createElement("b", null, route.shortName), " ", longName)), /*#__PURE__*/_react.default.createElement(_velocityReact.VelocityTransitionGroup, {
      enter: {
        animation: 'slideDown'
      },
      leave: {
        animation: 'slideUp'
      }
    }, isActive && /*#__PURE__*/_react.default.createElement(RouteDetails, null, route.url ? /*#__PURE__*/_react.default.createElement("a", {
      className: "routeDetails",
      href: route.url,
      target: "_blank"
    }, "Route Details") : 'No route URL provided.')));
  }

} // connect to redux store


_defineProperty(RouteRow, "contextType", _contexts.ComponentContext);

const mapStateToProps = (state, ownProps) => {
  return {
    languageConfig: state.otp.config.language,
    routes: state.otp.transitIndex.routes,
    transitOperators: state.otp.config.transitOperators,
    viewedRoute: state.otp.ui.viewedRoute
  };
};

const mapDispatchToProps = {
  findRoute: _api.findRoute,
  findRoutes: _api.findRoutes,
  setMainPanelContent: _ui.setMainPanelContent,
  setViewedRoute: _ui.setViewedRoute
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(RouteViewer);

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=route-viewer.js